net: phy: realtek: improve firmware write speed

Firmware execution routine unconditionally uses phy_modify_mmd() for
all OP_WRITE entries which introduces an unnecessary read transaction
when updating an entire 16-bit register. So we optimize this by
checking bitmask boundaries. Use phy_write_mmd() directly to speed up
firmware loading process.

Benchmark number from tracing MDC/MDIO hardware transactions during
firmware loading process:
 - Unpatched: about 28,000 MDIO transactions
 - Patched: about 9,600 MDIO transactions
This results in an approx 65% reduction in MDIO traffic.

Signed-off-by: Javen Xu <javen_xu@realsil.com.cn>
Reviewed-by: Nicolai Buchwitz <nb@tipi-net.de>
Reviewed-by: Andrew Lunn <andrew@lunn.ch>
Link: https://patch.msgid.link/20260911094527.1928-1-javen_xu@realsil.com.cn
Signed-off-by: Jakub Kicinski <kuba@kernel.org>
This commit is contained in:
Javen Xu 2026-09-11 17:45:27 +08:00 • committed by Jakub Kicinski
commit 3d989d1f40